@@ -1,4 +1,5 @@
 test_that("save numbers in JSON works", {
+
   # set no hashing
   options(reproducibleRchunks.hashing = FALSE)
   mydata <- 1:10
@@ -7,6 +8,10 @@ test_that("save numbers in JSON works", {
                                         filename = filename,
                                         filetype = "json")
 
+  on.exit({
+    unlink(filename)
+  }, add = TRUE)
+
   test_envir <- new.env()
   reproducibleRchunks::load_repro_data(filename,
                                         filetype = "json",
